import React, { PureComponent } from 'react';
import { Image, Dimensions } from 'react-native';
import PropTypes from 'prop-types';
import ImageZoom from 'react-native-image-pan-zoom';

const window = Dimensions.get('window');
const w = window.width;
const h = window.height;

class ImageCropper extends PureComponent {
  constructor() {
    super();
    this.imageZoom = React.createRef();
  }

  state = {
    positionX: 0,
    positionY: 0,
    width: 0,
    height: 0,
    minScale: 1.01,
    adjustedHeight: 0,
    loading: true,
  };

  static propTypes = {
    imageUri: PropTypes.string.isRequired,
    setCropperParams: PropTypes.func.isRequired,
  };

  componentDidMount() {
    const { imageUri } = this.props;

    Image.getSize(imageUri, (width, height) => {
      const { setCropperParams } = this.props;

      const srcSize = { w: width, h: height };
      const fittedSize = { w: 0, h: 0 };
      let scale = 1.01;

      const screenSize = {
        w,
        h,
      };

      if (width > height) {
        const ratio = w / height;
        fittedSize.w = width * ratio;
        fittedSize.h = w;
      } else if (width < height) {
        const ratio = w / width;
        fittedSize.w = w;
        fittedSize.h = height * ratio;
      } else if (width === height) {
        scale = 1;
        fittedSize.w = w;
        fittedSize.h = w;
      }

      this.setState(
        prevState => ({
          ...prevState,
          screenSize,
          srcSize,
          fittedSize,
          minScale: scale,
          loading: false,
        }),
        () => {
          this.imageZoom.current.centerOn({
            x: 0,
            y: 0,
            scale,
            duration: 0,
          });
          setCropperParams(this.state);
        },
      );
    });
  }

  handleMove = ({ positionX, positionY, scale }) => {
    const { setCropperParams } = this.props;

    this.setState(
      prevState => ({
        ...prevState,
        positionX,
        positionY,
        scale,
      }),
      () => setCropperParams(this.state),
    );
  };

  render() {
    const { loading, fittedSize, minScale } = this.state;
    const { imageUri, ...restProps } = this.props;
    const imageSrc = { uri: imageUri };

    return !loading ? (
      <ImageZoom
        ref={this.imageZoom}
        {...restProps}
        cropWidth={w}
        cropHeight={w}
        imageWidth={fittedSize.w}
        imageHeight={fittedSize.h}
        minScale={minScale}
        onMove={this.handleMove}
      >
        <Image style={{ width: fittedSize.w, height: fittedSize.h }} source={imageSrc} />
      </ImageZoom>
    ) : null;
  }
}

export default ImageCropper;
