import { ImageEditor } from 'react-native';
import { getPercentFromNumber, getPercentDiffNumberFromNumber } from '../helpers/percentCalculator';

export default params => {
  const {
    imageUri,
    cropSize,
    positionX,
    positionY,
    screenSize,
    srcSize,
    fittedSize,
    scale,
  } = params;

  const offset = {
    x: 0,
    y: 0,
  };

  const wScale = screenSize.w / scale;
  const percentCropperAreaW = getPercentDiffNumberFromNumber(wScale, fittedSize.w);
  const percentRestW = 100 - percentCropperAreaW;
  const hiddenAreaW = getPercentFromNumber(percentRestW, fittedSize.w);

  const percentCropperAreaH = getPercentDiffNumberFromNumber(wScale, fittedSize.h);
  const percentRestH = 100 - percentCropperAreaH;
  const hiddenAreaH = getPercentFromNumber(percentRestH, fittedSize.h);

  const x = hiddenAreaW / 2 - positionX;
  const y = hiddenAreaH / 2 - positionY;

  offset.x = x <= 0 ? 0 : x;
  offset.y = y <= 0 ? 0 : y;

  const srcPercentCropperAreaW = getPercentDiffNumberFromNumber(offset.x, fittedSize.w);
  const srcPercentCropperAreaH = getPercentDiffNumberFromNumber(offset.y, fittedSize.h);

  const offsetW = getPercentFromNumber(srcPercentCropperAreaW, srcSize.w);
  const offsetH = getPercentFromNumber(srcPercentCropperAreaH, srcSize.h);

  const sizeW = getPercentFromNumber(percentCropperAreaW, srcSize.w);
  const sizeH = getPercentFromNumber(percentCropperAreaH, srcSize.h);

  offset.x = offsetW;
  offset.y = offsetH;

  const cropData = {
    offset,
    size: {
      width: sizeW,
      height: sizeH,
    },
    displaySize: {
      width: cropSize.width,
      height: cropSize.height,
    },
  };

  return new Promise((resolve, reject) =>
    ImageEditor.cropImage(imageUri, cropData, resolve, reject),
  );
};
